pub struct UserDataStream { /* private fields */ }Expand description
Handle for a user data stream. Same shape as WebSocketStream but for private events.
Dropping this handle aborts the background task.
Implementations
Sourceimpl UserDataStream
impl UserDataStream
Sourcepub async fn recv(&mut self) -> Option<Result<Value, AsterDexError>>
pub async fn recv(&mut self) -> Option<Result<Value, AsterDexError>>
Receive the next user data event from the stream.
Returns None when the stream is closed (background task ended).
Sourcepub async fn next_event(
&mut self,
) -> Option<Result<UserDataEvent, AsterDexError>>
pub async fn next_event( &mut self, ) -> Option<Result<UserDataEvent, AsterDexError>>
Receive the next user data event as a typed UserDataEvent.